#
# Part of the wxWidgets-CMake project
#
# (c)2013 Brian Sidebotham
#
# Provided under the wxWindows licence
# http://opensource.org/licenses/wxwindows.php
# A copy of the licence can also be found in the LICENCE file
#


#
# wx_get_version( VAR )
#
# Sets VAR to the wxWidgets version from the source code version infomation. VAR
# is set to MAJORMINOR, so for example when compiling wxWidgets 2.9.4.0, VAR is
# set to 29. This value is used to version the libraries filenames.
#
# The function also sets the following variables at the calling scope (Example
# value when compiling 2.9.4.0):
#
# VAR_MAJOR - Just the major version component   (2)
# VAR_MINOR - Just the minor version component   (9)
# VAR_RELEASE - Just the relase component        (4)
# VAR_SUBRELEASE - Just the subrelease component (0)
# VAR_FULL - The complete version                (2.9.4.0)

FUNCTION( wx_get_version OUT )

    file( STRINGS ${PROJECT_SOURCE_DIR}/include/wx/version.h WX_VER_STR
        REGEX "wx(MAJOR|MINOR|RELEASE|SUBRELEASE)_(VERSION|NUMBER)[ ]+[0-9]+" )

    foreach( STR ${WX_VER_STR} )

        if( ${STR} MATCHES "wxMAJOR_VERSION" )
            string( REGEX REPLACE "(#define[ ]+wxMAJOR_VERSION[ ]+)([0-9]+)" "\\2" WXMAJOR_VERSION  ${STR} )
        endif()

        if( ${STR} MATCHES "wxMINOR_VERSION" )
            string( REGEX REPLACE "(#define[ ]+wxMINOR_VERSION[ ]+)([0-9]+)" "\\2" WXMINOR_VERSION  ${STR} )
        endif()

        if( ${STR} MATCHES "wxRELEASE_NUMBER" )
            string( REGEX REPLACE "(#define[ ]+wxRELEASE_NUMBER[ ]+)([0-9]+)" "\\2" WXRELEASE_NUMBER  ${STR} )
        endif()

        if( ${STR} MATCHES "wxSUBRELEASE_NUMBER" )
            string( REGEX REPLACE "(#define[ ]+wxSUBRELEASE_NUMBER[ ]+)([0-9]+)" "\\2" WXSUBRELEASE_NUMBER  ${STR} )
        endif()

    endforeach()

    set( ${OUT} "${WXMAJOR_VERSION}${WXMINOR_VERSION}" PARENT_SCOPE )
    set( ${OUT}_MAJOR ${WXMAJOR_VERSION} PARENT_SCOPE )
    set( ${OUT}_MINOR ${WXMINOR_VERSION} PARENT_SCOPE )
    set( ${OUT}_RELEASE ${WXRELEASE_NUMBER} PARENT_SCOPE )
    set( ${OUT}_SUBRELEASE ${WXSUBRELEASE_NUMBER} PARENT_SCOPE )
    set( ${OUT}_FULL "${WXMAJOR_VERSION}.${WXMINOR_VERSION}.${WXRELEASE_NUMBER}.${WXSUBRELEASE_NUMBER}" PARENT_SCOPE )

ENDFUNCTION()