#
# Part of the wxWidgets-CMake project
#
# (c)2013 Brian Sidebotham
#
# Provided under the wxWindows licence
# http://opensource.org/licenses/wxwindows.php
# A copy of the licence can also be found in the LICENCE file
#

message( STATUS "Building Python Bindings" )

if( NOT PYMINGWLIBS_FOUND )
    message( STATUS "Cannot find Python-a-mingw-us libraries!" )
endif()

# --- Setup the output directory structure -----------------------------------

set( PYVERSION wx-${WXVERSION_MAJOR}.${WXVERSION_MINOR}.${WXVERSION_RELEASE}-${WXSYSTEM} )
set( PYBASE_DIR "${CMAKE_CURRENT_BINARY_DIR}/wxpython" )
set( PYBUILD_DIR "${CMAKE_CURRENT_BINARY_DIR}/wxpython/${PYVERSION}" )
set( PYLIB_DIR "${PYBUILD_DIR}/wx" )

file( MAKE_DIRECTORY ${PYLIB_DIR} )

if( NOT EXISTS "${PYBASE_DIR}/wxversion.py" )
    file( COPY "${PROJECT_SOURCE_DIR}/wxPython/wxversion/wxversion.py"
        DESTINATION "${PYBASE_DIR}" )
endif()

if( NOT EXISTS "${PYBASE_DIR}/wx.pth" )
    file( WRITE "${PYBASE_DIR}/wx.pth" "${PYVERSION}" )
endif()

if( WIN32 OR MINGW )
    set( WXPYMACH_DIR "${PROJECT_SOURCE_DIR}/wxPython/src/msw" )
endif()

# The installation target for wxPython is to simply include the entire output
# directory. The build is structured to build the correct structure in-place
install( DIRECTORY "${PYBASE_DIR}" DESTINATION "./" )
install( DIRECTORY "${PROJECT_SOURCE_DIR}/wxPython/include/wx" DESTINATION "./include" )

# Also make a copy of the include directory for wxPython in the build
# directory so the build directory can be used as a target for cmake projects
file( COPY "${PROJECT_SOURCE_DIR}/wxPython/include/wx" DESTINATION "${PROJECT_BINARY_DIR}/include" )

# --- Generate the version file ---------------------------------------------

set( VERFILE "${PYLIB_DIR}/__version__.py" )

file( WRITE ${VERFILE}
    "# This file was created by wxpython.cmake\n"
    "\n"
    "VERSION_STRING = '${WXVERSION_MAJOR}.${WXVERSION_MINOR}.${WXVERSION_RELEASE}.${WXVERSION_SUBRELEASE}'\n"
    "MAJOR_VERSION = ${WXVERSION_MAJOR}\n"
    "MINOR_VERSION = ${WXVERSION_MINOR}\n"
    "RELEASE_VERSION = ${WXVERSION_RELEASE}\n"
    "SUBREL_VERSION = ${WXVERSION_SUBRELEASE}\n"
    "VERSION = ( MAJOR_VERSION, MINOR_VERSION, RELEASE_VERSION, SUBREL_VERSION, '' )\n"
    "\n" )

# -- Copy non-build files ----------------------------------------------------

file( COPY ${PROJECT_SOURCE_DIR}/wxPython/wx DESTINATION ${PYBUILD_DIR} )
file( COPY ${PROJECT_SOURCE_DIR}/wxPython/src/__init__.py DESTINATION ${PYLIB_DIR} )
file( GLOB PYSRCS "${WXPYMACH_DIR}/*.py" )

foreach( PYSRC ${PYSRCS} )
    file( COPY ${PYSRC} DESTINATION ${PYLIB_DIR} )
endforeach()


# --- Include some required directories --------------------------------------

include_directories( ${PYTHON_INCLUDE_DIRS} )
include_directories( ${PROJECT_SOURCE_DIR}/wxPython/include )

# --- _CORE_ -----------------------------------------------------------------

set( WXPYCORE_SRCS
    ${PROJECT_SOURCE_DIR}/wxPython/src/helpers.cpp
    ${WXPYMACH_DIR}/_core_wrap.cpp )

if( WIN32 OR MINGW )
    set( WXPYCORE_SRCS ${WXPYCORE_SRCS} ${PROJECT_SOURCE_DIR}/wxPython/src/wxc.rc )
endif()

add_library( _core_ SHARED ${WXPYCORE_SRCS} )

set_target_properties( _core_
        PROPERTIES COMPILE_FLAGS "-mthreads -fmessage-length=0 -Wno-ctor-dtor-privacy -DHAVE_STDINT_H -DSWIG_TYPE_TABLE=_wxPython_table -DSWIG_PYTHON_OUTPUT_TUPLE -DWXP_USE_THREAD=1 -DWXUSINGDLL -D_UNICODE -I${PYMINGWLIBS_INCLUDE_DIRS} -I${PROJECT_SOURCE_DIR}/wxPython/include"
        RUNTIME_OUTPUT_DIRECTORY "${PYLIB_DIR}"
        PREFIX ""
        SUFFIX ".pyd" )

target_link_libraries( _core_
        ${REQUIRED_LIBS}
        adv
        net
        core
        base
        ${PYTHON_LIBRARIES} )

# --- _GDI_ ------------------------------------------------------------------

set( WXPYGDI_SRCS
    ${PROJECT_SOURCE_DIR}/wxPython/src/drawlist.cpp
    ${PROJECT_SOURCE_DIR}/wxPython/src/pseudodc.cpp
    ${WXPYMACH_DIR}/_gdi_wrap.cpp )

add_library( _gdi_ SHARED ${WXPYGDI_SRCS} )

set_target_properties( _gdi_
        PROPERTIES COMPILE_FLAGS "-mthreads -fmessage-length=0 -Wno-ctor-dtor-privacy -DHAVE_STDINT_H -DSWIG_TYPE_TABLE=_wxPython_table -DSWIG_PYTHON_OUTPUT_TUPLE -DWXP_USE_THREAD=1 -DWXUSINGDLL -D_UNICODE -I${PYMINGWLIBS_INCLUDE_DIRS} -I${PROJECT_SOURCE_DIR}/wxPython/include"
        RUNTIME_OUTPUT_DIRECTORY "${PYLIB_DIR}"
        PREFIX ""
        SUFFIX ".pyd" )

target_link_libraries( _gdi_
        ${REQUIRED_LIBS}
        core
        base
        ${PYTHON_LIBRARIES} )

# --- _WINDOWS_ --------------------------------------------------------------

set( WXPYWIN_SRCS
    ${WXPYMACH_DIR}/_windows_wrap.cpp )

add_library( _windows_ SHARED ${WXPYWIN_SRCS} )

set_target_properties( _windows_
        PROPERTIES COMPILE_FLAGS "-mthreads -fmessage-length=0 -Wno-ctor-dtor-privacy -DHAVE_STDINT_H -DSWIG_TYPE_TABLE=_wxPython_table -DSWIG_PYTHON_OUTPUT_TUPLE -DWXP_USE_THREAD=1 -DWXUSINGDLL -D_UNICODE -I${PYMINGWLIBS_INCLUDE_DIRS} -I${PROJECT_SOURCE_DIR}/wxPython/include"
        RUNTIME_OUTPUT_DIRECTORY "${PYLIB_DIR}"
        PREFIX ""
        SUFFIX ".pyd" )

target_link_libraries( _windows_
        ${REQUIRED_LIBS}
        adv
        html
        core
        base
        ${PYTHON_LIBRARIES} )

# --- _CONTROLS_ -------------------------------------------------------------

set( WXPYCTRL_SRCS
    ${WXPYMACH_DIR}/_controls_wrap.cpp )

add_library( _controls_ SHARED ${WXPYCTRL_SRCS} )

set_target_properties( _controls_
        PROPERTIES COMPILE_FLAGS "-mthreads -fmessage-length=0 -Wno-ctor-dtor-privacy -DHAVE_STDINT_H -DSWIG_TYPE_TABLE=_wxPython_table -DSWIG_PYTHON_OUTPUT_TUPLE -DWXP_USE_THREAD=1 -DWXUSINGDLL -D_UNICODE -I${PYMINGWLIBS_INCLUDE_DIRS} -I${PROJECT_SOURCE_DIR}/wxPython/include"
        RUNTIME_OUTPUT_DIRECTORY "${PYLIB_DIR}"
        PREFIX ""
        SUFFIX ".pyd" )

target_link_libraries( _controls_
        ${REQUIRED_LIBS}
        adv
        core
        base
        ${PYTHON_LIBRARIES} )

# --- _MISC_ -----------------------------------------------------------------

set( WXPYMISC_SRCS
    ${WXPYMACH_DIR}/_misc_wrap.cpp )

add_library( _misc_ SHARED ${WXPYMISC_SRCS} )

set_target_properties( _misc_
        PROPERTIES COMPILE_FLAGS "-mthreads -fmessage-length=0 -Wno-ctor-dtor-privacy -DHAVE_STDINT_H -DSWIG_TYPE_TABLE=_wxPython_table -DSWIG_PYTHON_OUTPUT_TUPLE -DWXP_USE_THREAD=1 -DWXUSINGDLL -D_UNICODE -I${PYMINGWLIBS_INCLUDE_DIRS} -I${PROJECT_SOURCE_DIR}/wxPython/include"
        RUNTIME_OUTPUT_DIRECTORY "${PYLIB_DIR}"
        PREFIX ""
        SUFFIX ".pyd" )

target_link_libraries( _misc_
        ${REQUIRED_LIBS}
        adv
        core
        base
        ${PYTHON_LIBRARIES} )

# --- _CALENDAR --------------------------------------------------------------

set( WXPYCAL_SRCS
    ${WXPYMACH_DIR}/calendar_wrap.cpp )

add_library( _calendar SHARED ${WXPYCAL_SRCS} )

set_target_properties( _calendar
        PROPERTIES COMPILE_FLAGS "-mthreads -fmessage-length=0 -Wno-ctor-dtor-privacy -DHAVE_STDINT_H -DSWIG_TYPE_TABLE=_wxPython_table -DSWIG_PYTHON_OUTPUT_TUPLE -DWXP_USE_THREAD=1 -DWXUSINGDLL -D_UNICODE -I${PYMINGWLIBS_INCLUDE_DIRS} -I${PROJECT_SOURCE_DIR}/wxPython/include"
        RUNTIME_OUTPUT_DIRECTORY "${PYLIB_DIR}"
        PREFIX ""
        SUFFIX ".pyd" )

target_link_libraries( _calendar
        ${REQUIRED_LIBS}
        adv
        core
        base
        ${PYTHON_LIBRARIES} )

# --- _COMBO -----------------------------------------------------------------

set( WXPYCOM_SRCS
    ${WXPYMACH_DIR}/combo_wrap.cpp )

add_library( _combo SHARED ${WXPYCOM_SRCS} )

set_target_properties( _combo
        PROPERTIES COMPILE_FLAGS "-mthreads -fmessage-length=0 -Wno-ctor-dtor-privacy -DHAVE_STDINT_H -DSWIG_TYPE_TABLE=_wxPython_table -DSWIG_PYTHON_OUTPUT_TUPLE -DWXP_USE_THREAD=1 -DWXUSINGDLL -D_UNICODE -I${PYMINGWLIBS_INCLUDE_DIRS} -I${PROJECT_SOURCE_DIR}/wxPython/include"
        RUNTIME_OUTPUT_DIRECTORY "${PYLIB_DIR}"
        PREFIX ""
        SUFFIX ".pyd" )

target_link_libraries( _combo
        ${REQUIRED_LIBS}
        adv
        core
        base
        ${PYTHON_LIBRARIES} )

# --- _GRID -----------------------------------------------------------------

set( WXPYGRID_SRCS
    ${WXPYMACH_DIR}/grid_wrap.cpp )

add_library( _grid SHARED ${WXPYGRID_SRCS} )

set_target_properties( _grid
        PROPERTIES COMPILE_FLAGS "-mthreads -fmessage-length=0 -Wno-ctor-dtor-privacy -DHAVE_STDINT_H -DSWIG_TYPE_TABLE=_wxPython_table -DSWIG_PYTHON_OUTPUT_TUPLE -DWXP_USE_THREAD=1 -DWXUSINGDLL -D_UNICODE -I${PYMINGWLIBS_INCLUDE_DIRS} -I${PROJECT_SOURCE_DIR}/wxPython/include"
        RUNTIME_OUTPUT_DIRECTORY "${PYLIB_DIR}"
        PREFIX ""
        SUFFIX ".pyd" )

target_link_libraries( _grid
        ${REQUIRED_LIBS}
        adv
        core
        base
        ${PYTHON_LIBRARIES} )

# --- _HTML -----------------------------------------------------------------

set( WXPYHTML_SRCS
    ${WXPYMACH_DIR}/html_wrap.cpp )

add_library( _html SHARED ${WXPYHTML_SRCS} )

set_target_properties( _html
        PROPERTIES COMPILE_FLAGS "-mthreads -fmessage-length=0 -Wno-ctor-dtor-privacy -DHAVE_STDINT_H -DSWIG_TYPE_TABLE=_wxPython_table -DSWIG_PYTHON_OUTPUT_TUPLE -DWXP_USE_THREAD=1 -DWXUSINGDLL -D_UNICODE -I${PYMINGWLIBS_INCLUDE_DIRS} -I${PROJECT_SOURCE_DIR}/wxPython/include"
        RUNTIME_OUTPUT_DIRECTORY "${PYLIB_DIR}"
        PREFIX ""
        SUFFIX ".pyd" )

target_link_libraries( _html
        ${REQUIRED_LIBS}
        html
        core
        base
        ${PYTHON_LIBRARIES} )

# --- _MEDIA -----------------------------------------------------------------

set( WXPYMEDIA_SRCS
    ${WXPYMACH_DIR}/media_wrap.cpp )

add_library( _media SHARED ${WXPYMEDIA_SRCS} )

set_target_properties( _media
        PROPERTIES COMPILE_FLAGS "-mthreads -fmessage-length=0 -Wno-ctor-dtor-privacy -DHAVE_STDINT_H -DSWIG_TYPE_TABLE=_wxPython_table -DSWIG_PYTHON_OUTPUT_TUPLE -DWXP_USE_THREAD=1 -DWXUSINGDLL -D_UNICODE -I${PYMINGWLIBS_INCLUDE_DIRS} -I${PROJECT_SOURCE_DIR}/wxPython/include"
        RUNTIME_OUTPUT_DIRECTORY "${PYLIB_DIR}"
        PREFIX ""
        SUFFIX ".pyd" )

target_link_libraries( _media
        ${REQUIRED_LIBS}
        media
        core
        base
        ${PYTHON_LIBRARIES} )

# --- _WEBKIT ----------------------------------------------------------------

set( WXPYWKIT_SRCS
    ${WXPYMACH_DIR}/webkit_wrap.cpp )

add_library( _webkit SHARED ${WXPYWKIT_SRCS} )

set_target_properties( _webkit
        PROPERTIES COMPILE_FLAGS "-mthreads -fmessage-length=0 -Wno-ctor-dtor-privacy -DHAVE_STDINT_H -DSWIG_TYPE_TABLE=_wxPython_table -DSWIG_PYTHON_OUTPUT_TUPLE -DWXP_USE_THREAD=1 -DWXUSINGDLL -D_UNICODE -I${PYMINGWLIBS_INCLUDE_DIRS} -I${PROJECT_SOURCE_DIR}/wxPython/include"
        RUNTIME_OUTPUT_DIRECTORY "${PYLIB_DIR}"
        PREFIX ""
        SUFFIX ".pyd" )

target_link_libraries( _webkit
        ${REQUIRED_LIBS}
        core
        base
        ${PYTHON_LIBRARIES} )

# --- _WIZARD ----------------------------------------------------------------

set( WXPYWIZ_SRCS
    ${WXPYMACH_DIR}/wizard_wrap.cpp )

add_library( _wizard SHARED ${WXPYWIZ_SRCS} )

set_target_properties( _wizard
        PROPERTIES COMPILE_FLAGS "-mthreads -fmessage-length=0 -Wno-ctor-dtor-privacy -DHAVE_STDINT_H -DSWIG_TYPE_TABLE=_wxPython_table -DSWIG_PYTHON_OUTPUT_TUPLE -DWXP_USE_THREAD=1 -DWXUSINGDLL -D_UNICODE -I${PYMINGWLIBS_INCLUDE_DIRS} -I${PROJECT_SOURCE_DIR}/wxPython/include"
        RUNTIME_OUTPUT_DIRECTORY "${PYLIB_DIR}"
        PREFIX ""
        SUFFIX ".pyd" )

target_link_libraries( _wizard
        ${REQUIRED_LIBS}
        adv
        core
        base
        ${PYTHON_LIBRARIES} )

# --- _DATAVIEW --------------------------------------------------------------

set( WXPYDATA_SRCS
    ${WXPYMACH_DIR}/dataview_wrap.cpp )

add_library( _dataview SHARED ${WXPYDATA_SRCS} )

set_target_properties( _dataview
        PROPERTIES COMPILE_FLAGS "-mthreads -fmessage-length=0 -Wno-ctor-dtor-privacy -DHAVE_STDINT_H -DSWIG_TYPE_TABLE=_wxPython_table -DSWIG_PYTHON_OUTPUT_TUPLE -DWXP_USE_THREAD=1 -DWXUSINGDLL -D_UNICODE -I${PYMINGWLIBS_INCLUDE_DIRS} -I${PROJECT_SOURCE_DIR}/wxPython/include"
        RUNTIME_OUTPUT_DIRECTORY "${PYLIB_DIR}"
        PREFIX ""
        SUFFIX ".pyd" )

target_link_libraries( _dataview
        ${REQUIRED_LIBS}
        adv
        core
        base
        ${PYTHON_LIBRARIES} )

# --- _XRC -------------------------------------------------------------------

set( WXPYXRC_SRCS
    ${WXPYMACH_DIR}/xrc_wrap.cpp )

add_library( _xrc SHARED ${WXPYXRC_SRCS} )

set_target_properties( _xrc
        PROPERTIES COMPILE_FLAGS "-mthreads -fmessage-length=0 -Wno-ctor-dtor-privacy -DHAVE_STDINT_H -DSWIG_TYPE_TABLE=_wxPython_table -DSWIG_PYTHON_OUTPUT_TUPLE -DWXP_USE_THREAD=1 -DWXUSINGDLL -D_UNICODE -I${PYMINGWLIBS_INCLUDE_DIRS} -I${PROJECT_SOURCE_DIR}/wxPython/include"
        RUNTIME_OUTPUT_DIRECTORY "${PYLIB_DIR}"
        PREFIX ""
        SUFFIX ".pyd" )

target_link_libraries( _xrc
        ${REQUIRED_LIBS}
        xrc
        core
        base
        ${PYTHON_LIBRARIES} )

# --- _RICHTEXT --------------------------------------------------------------

set( WXPYRICH_SRCS
    ${WXPYMACH_DIR}/richtext_wrap.cpp )

add_library( _richtext SHARED ${WXPYRICH_SRCS} )

set_target_properties( _richtext
        PROPERTIES COMPILE_FLAGS "-mthreads -fmessage-length=0 -Wno-ctor-dtor-privacy -DHAVE_STDINT_H -DSWIG_TYPE_TABLE=_wxPython_table -DSWIG_PYTHON_OUTPUT_TUPLE -DWXP_USE_THREAD=1 -DWXUSINGDLL -D_UNICODE -I${PYMINGWLIBS_INCLUDE_DIRS} -I${PROJECT_SOURCE_DIR}/wxPython/include"
        RUNTIME_OUTPUT_DIRECTORY "${PYLIB_DIR}"
        PREFIX ""
        SUFFIX ".pyd" )

target_link_libraries( _richtext
        ${REQUIRED_LIBS}
        richtext
        core
        base
        ${PYTHON_LIBRARIES} )

# --- _AUI --------------------------------------------------------------

set( WXPYAUI_SRCS
    ${WXPYMACH_DIR}/aui_wrap.cpp )

add_library( _aui SHARED ${WXPYAUI_SRCS} )

set_target_properties( _aui
        PROPERTIES COMPILE_FLAGS "-mthreads -fmessage-length=0 -Wno-ctor-dtor-privacy -DHAVE_STDINT_H -DSWIG_TYPE_TABLE=_wxPython_table -DSWIG_PYTHON_OUTPUT_TUPLE -DWXP_USE_THREAD=1 -DWXUSINGDLL -D_UNICODE -I${PYMINGWLIBS_INCLUDE_DIRS} -I${PROJECT_SOURCE_DIR}/wxPython/include"
        RUNTIME_OUTPUT_DIRECTORY "${PYLIB_DIR}"
        PREFIX ""
        SUFFIX ".pyd" )

target_link_libraries( _aui
        ${REQUIRED_LIBS}
        aui
        html
        xml
        adv
        core
        base
        ${PYTHON_LIBRARIES} )

# --- _ANIMATE ---------------------------------------------------------------

set( WXPYANIM_SRCS
    ${WXPYMACH_DIR}/animate_wrap.cpp )

add_library( _animate SHARED ${WXPYANIM_SRCS} )

set_target_properties( _animate
        PROPERTIES COMPILE_FLAGS "-mthreads -fmessage-length=0 -Wno-ctor-dtor-privacy -DHAVE_STDINT_H -DSWIG_TYPE_TABLE=_wxPython_table -DSWIG_PYTHON_OUTPUT_TUPLE -DWXP_USE_THREAD=1 -DWXUSINGDLL -D_UNICODE -I${PYMINGWLIBS_INCLUDE_DIRS} -I${PROJECT_SOURCE_DIR}/wxPython/include"
        RUNTIME_OUTPUT_DIRECTORY "${PYLIB_DIR}"
        PREFIX ""
        SUFFIX ".pyd" )

target_link_libraries( _animate
        ${REQUIRED_LIBS}
        adv
        core
        base
        ${PYTHON_LIBRARIES} )

# --- _PROPGRID --------------------------------------------------------------

set( WXPYPROP_SRCS
    ${WXPYMACH_DIR}/propgrid_wrap.cpp )

add_library( _propgrid SHARED ${WXPYPROP_SRCS} )

set_target_properties( _propgrid
        PROPERTIES COMPILE_FLAGS "-mthreads -fmessage-length=0 -Wno-ctor-dtor-privacy -DHAVE_STDINT_H -DSWIG_TYPE_TABLE=_wxPython_table -DSWIG_PYTHON_OUTPUT_TUPLE -DWXP_USE_THREAD=1 -DWXUSINGDLL -D_UNICODE -I${PYMINGWLIBS_INCLUDE_DIRS} -I${PROJECT_SOURCE_DIR}/wxPython/include"
        RUNTIME_OUTPUT_DIRECTORY "${PYLIB_DIR}"
        PREFIX ""
        SUFFIX ".pyd" )

target_link_libraries( _propgrid
        ${REQUIRED_LIBS}
        propgrid
        core
        base
        ${PYTHON_LIBRARIES} )

# --- _HTML2 --------------------------------------------------------------

set( WXPYHTML2_SRCS
    ${WXPYMACH_DIR}/html2_wrap.cpp )

add_library( _html2 SHARED ${WXPYHTML2_SRCS} )

set_target_properties( _html2
        PROPERTIES COMPILE_FLAGS "-mthreads -fmessage-length=0 -Wno-ctor-dtor-privacy -DHAVE_STDINT_H -DSWIG_TYPE_TABLE=_wxPython_table -DSWIG_PYTHON_OUTPUT_TUPLE -DWXP_USE_THREAD=1 -DWXUSINGDLL -D_UNICODE -I${PYMINGWLIBS_INCLUDE_DIRS} -I${PROJECT_SOURCE_DIR}/wxPython/include"
        RUNTIME_OUTPUT_DIRECTORY "${PYLIB_DIR}"
        PREFIX ""
        SUFFIX ".pyd" )

target_link_libraries( _html2
        ${REQUIRED_LIBS}
        webview
        core
        base
        ${PYTHON_LIBRARIES} )

# --- _STC -------------------------------------------------------------------

set( WXPYSTC_SRCS
    ${WXPYMACH_DIR}/stc_wrap.cpp )

add_library( _stc SHARED ${WXPYSTC_SRCS} )

set_target_properties( _stc
        PROPERTIES COMPILE_FLAGS "-mthreads -fmessage-length=0 -Wno-ctor-dtor-privacy -DHAVE_STDINT_H -DSWIG_TYPE_TABLE=_wxPython_table -DSWIG_PYTHON_OUTPUT_TUPLE -DWXP_USE_THREAD=1 -DWXUSINGDLL -D_UNICODE -I${PYMINGWLIBS_INCLUDE_DIRS} -I${PROJECT_SOURCE_DIR}/wxPython/include"
        RUNTIME_OUTPUT_DIRECTORY "${PYLIB_DIR}"
        PREFIX ""
        SUFFIX ".pyd" )

target_link_libraries( _stc
        ${REQUIRED_LIBS}
        stc
        core
        base
        ${PYTHON_LIBRARIES} )

# --- _GLCANVAS --------------------------------------------------------------

set( WXPYGL_SRCS
    ${WXPYMACH_DIR}/glcanvas_wrap.cpp )

add_library( _glcanvas SHARED ${WXPYGL_SRCS} )

set_target_properties( _glcanvas
        PROPERTIES COMPILE_FLAGS "-mthreads -fmessage-length=0 -Wno-ctor-dtor-privacy -DHAVE_STDINT_H -DSWIG_TYPE_TABLE=_wxPython_table -DSWIG_PYTHON_OUTPUT_TUPLE -DWXP_USE_THREAD=1 -DWXUSINGDLL -D_UNICODE -I${PYMINGWLIBS_INCLUDE_DIRS} -I${PROJECT_SOURCE_DIR}/wxPython/include"
        RUNTIME_OUTPUT_DIRECTORY "${PYLIB_DIR}"
        PREFIX ""
        SUFFIX ".pyd" )

target_link_libraries( _glcanvas
        ${REQUIRED_LIBS}
        gl
        core
        base
        ${PYTHON_LIBRARIES} )

# --- _GIZMOS ----------------------------------------------------------------

# Only include the Gizmo's contrib wxCode project if it exists in the wxWidgets
# project
if( 0 )

    include_directories( ${PROJECT_SOURCE_DIR}/wxPython/contrib/gizmos/wxCode/include )

    set( WXPYGIZ_SRCS
        ${PROJECT_SOURCE_DIR}/wxPython/contrib/gizmos/wxCode/src/treelistctrl.cpp
        ${PROJECT_SOURCE_DIR}/wxPython/contrib/gizmos/wxCode/src/gizmos/dynamicsash.cpp
        ${PROJECT_SOURCE_DIR}/wxPython/contrib/gizmos/wxCode/src/gizmos/ledctrl.cpp
        ${PROJECT_SOURCE_DIR}/wxPython/contrib/gizmos/wxCode/src/gizmos/splittree.cpp
        ${PROJECT_SOURCE_DIR}/wxPython/contrib/gizmos/wxCode/src/gizmos/statpict.cpp
        ${PROJECT_SOURCE_DIR}/wxPython/contrib/gizmos/msw/gizmos_wrap.cpp )

    set( GIZ_INCLUDE_DIRS "-I${PROJECT_SOURCE_DIR}/wxPython/contrib/gizmos/wxCode/include" )

    add_library( _gizmos SHARED ${WXPYGIZ_SRCS} )

    set_target_properties( _gizmos
        PROPERTIES COMPILE_FLAGS "-mthreads -fmessage-length=0 -Wno-ctor-dtor-privacy -DHAVE_STDINT_H -DSWIG_TYPE_TABLE=_wxPython_table -DSWIG_PYTHON_OUTPUT_TUPLE -DWXP_USE_THREAD=1 -DWXUSINGDLL -D_UNICODE ${GIZ_INCLUDE_DIRS} -I${PYMINGWLIBS_INCLUDE_DIRS} -I${PROJECT_SOURCE_DIR}/wxPython/include"
        RUNTIME_OUTPUT_DIRECTORY "${PYLIB_DIR}"
        PREFIX ""
        SUFFIX ".pyd" )

    target_link_libraries( _gizmos
        ${REQUIRED_LIBS}
        adv
        core
        base
        ${PYTHON_LIBRARIES} )

endif()
